@@ -26,6 +26,7 @@ import re
 
 from pymatgen.core.periodic_table import DummySpecie
 from pymatgen.core.structure import Molecule
+from pymatgen.core.structure import Structure
 from turbomoleio.testfiles.utils import temp_dir, assert_MSONable
 from turbomoleio.core.molecule import Distance, BondAngle, DihedralAngle, InverseDistance, OutOfPlaneAngle
 from turbomoleio.core.molecule import CollinearBendingAngle, PerpendicularBendingAngle, InternalDefinition
@@ -79,6 +80,7 @@ def check_dg(to_test, ref):
         except ValueError:
             assert s == r
 
+
 def check_user_defined_bonds_dg(to_test, ref):
     """
     Helper function to check if the string of $user-defined bonds datagroup is
@@ -166,7 +168,7 @@ class TestInternalDefinition:
         assert da.is_valid(molecule)
 
         da = DihedralAngle(status="k", indices=[[0,1,2,3], [1,2,3,4], [0,2,3,4]],
-                          weights=[-0.1, 0.7, 0.7], value=-51.72110)
+                           weights=[-0.1, 0.7, 0.7], value=-51.72110)
         assert da.is_valid(molecule)
 
         assert str(da)
@@ -380,14 +382,14 @@ $end
         assert mol[1].coords[0] == pytest.approx(-0.6090991821345737)
         assert len(mol) == 4
 
-        assert ms.frozen_indices == {0,3}
+        assert ms.frozen_indices == {0, 3}
 
         assert len(ms.int_def) == 2
         assert ms.int_def[0].value == pytest.approx(2.43987)
-        assert ms.int_def[1].value == None
+        assert ms.int_def[1].value is None
         assert ms.int_def[0].status == "k"
         assert ms.int_def[1].status == "f"
-        assert ms.int_def[0].indices[0] == [0,1]
+        assert ms.int_def[0].indices[0] == [0, 1]
         assert len(ms.int_def[1].indices) == 2
         assert ms.int_def[1].weights[1] == pytest.approx(-0.5)
 
@@ -413,7 +415,7 @@ $end
         assert mol[1].coords[0] == pytest.approx(-0.6090991821345737)
         assert len(mol) == 4
 
-        assert ms.user_defined_bonds == {(0,"-",1), (1,"-",2), (2,"|",3)}
+        assert ms.user_defined_bonds == {(0, "-", 1), (1, "-", 2), (2, "|", 3)}
         dg = DataGroups(ms.to_coord_string())
         dg_ref = DataGroups(string)
         assert len(dg.dg_list) == 3
@@ -451,7 +453,7 @@ $end
         assert len(dg.dg_list) == 2
         check_dg(dg.sdg("coord", strict=True), test_value)
 
-        ms.frozen_indices = {0,1}
+        ms.frozen_indices = {0, 1}
         test_value = """
 0.00000000000000 0.00000000000000 0.00000000000000 c f
 0.00000000000000 0.00000000000000 2.86118897312869 o f
@@ -465,14 +467,11 @@ $end
     def test_dummy_atoms(self, molecule_filepath):
         ms = MoleculeSystem.from_file(molecule_filepath, fmt="coord")
         mol = ms.molecule
-        print(mol[-1].specie)
-        print(mol[-1].specie.__class__)
         # Pymatgen's Specie and DummySpecie have been changed to Species and
         # DummySpecies in v2020.10.9. We keep testing both for backward compatibility.
         assert isinstance(mol[-1].specie, (DummySpecies, DummySpecie))
         assert mol[-1].specie.symbol == "Q"
 
-
         test_value2 = """
 0.00000000000000 0.00000000000000 -0.12178983933899 o
 1.41713420892173 0.00000000000000 0.96657854674257 h
@@ -490,7 +489,7 @@ $end
         m = Molecule.from_file(molecule_filepath)
         assert not m.is_ordered
 
-        with pytest.raises(ValueError, match=r'^MoleculeSystem does not handle disordered structures.$'):
+        with pytest.raises(ValueError, match=r'^Turbomoleio and turbomole do not handle disordered structures.$'):
             MoleculeSystem(m).to_coord_string()
 
     @pytest.mark.parametrize('molecule_filename', ['co2.json'])
@@ -521,11 +520,11 @@ $end
         ms.add_distance(2, 3, value=10, weights=1.0)
         assert ms.has_inconsistencies()
 
-        ms.add_distance([0,1], [2,3])
+        ms.add_distance([0, 1], [2, 3])
         assert len(ms.int_def[-1].indices) == 2
 
         with pytest.raises(ValueError):
-            ms.add_distance([1,2,3], [1,2])
+            ms.add_distance([1, 2, 3], [1, 2])
 
         assert_MSONable(ms)
 
@@ -561,11 +560,11 @@ $end
         ms.add_dihedral(2, 3, 4, 1, value=10)
         assert ms.has_inconsistencies()
 
-        ms.add_dihedral([0,1], [2,3], [3,4], [1, 0])
+        ms.add_dihedral([0, 1], [2, 3], [3, 4], [1, 0])
         assert len(ms.int_def[-1].indices) == 2
 
         with pytest.raises(ValueError):
-            ms.add_dihedral([1,2,3], [1,2], [2,3], [3,4])
+            ms.add_dihedral([1, 2, 3], [1, 2], [2, 3], [3, 4])
 
     @pytest.mark.parametrize('molecule_filename', ['ch4.json'])
     def test_check_index(self, molecule):
